==> helmwave-0.36.3.tar.gz: helmwave-0.36.3/README.md <==
<p align="center">
  <a href="https://docs.helmwave.app?utm_source=github&utm_medium=project"><img alt="helwmave logo" src="https://raw.githubusercontent.com/helmwave/logo/main/signed_logo_top.svg" style="max-height:100%;" height="300px" /></a>
</p>

<p align="center">
  <a href="https://landscape.cncf.io/?selected=helmwave"><img src="https://img.shields.io/badge/CNCF_Landscape-helmwave-blue" alt="CNCF Landscape - helmwave"></a>
  <a href="https://github.com/helmwave/helmwave/blob/main/LICENSE"><img alt="license – MIT" src="https://img.shields.io/github/license/zhilyaev/helmwave"></a>
  <a href="https://bestpractices.coreinfrastructure.org/projects/5426"><img alt="best-practices" src="https://bestpractices.coreinfrastructure.org/projects/5426/badge"></a>
  <a href="https://codecov.io/gh/helmwave/helmwave"><img alt="codecov" src="https://codecov.io/gh/helmwave/helmwave/branch/main/graph/badge.svg?token=0WXxYhIG4S" /></a>
  <a href="https://www.codacy.com/gh/helmwave/helmwave/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=helmwave/helmwave&amp;utm_campaign=Badge_Grade"><img alt="codacy" src="https://app.codacy.com/project/badge/Grade/200ca37690b7463b976f1ece36b53a4e"/></a>
  <a href="https://www.codefactor.io/repository/github/helmwave/helmwave"><img src="https://www.codefactor.io/repository/github/helmwave/helmwave/badge" alt="CodeFactor" /></a>
  <a href="https://goreportcard.com/report/github.com/helmwave/helmwave"><img src="https://goreportcard.com/badge/github.com/helmwave/helmwave" alt="CodeFactor" /></a>
  <img alt="GitHub tag (latest SemVer)" src="https://img.shields.io/github/v/tag/zhilyaev/helmwave?label=latest">
</p>


🌊 Helmwave is **[helm3](https://github.com/helm/helm/)-native** tool for deploy your Helm Charts.

> We focus on speed execution, tiny size, pretty debugging.

With 🌊 helmwave you will become a superhero:

- Deploy multiple environments by one step
- Separate values for environments
- Common values for apps
- Keep a directory of chart value files
- Maintain changes in version control
- Template values
- Step by Step deployment (`depends_on`, `allow_failure`)
- Live tracking kubernetes resources with kubedog
- Fetch data from external datasource like vault, aws sm, sops
- ... and much more!

[![asciicast](https://asciinema.org/a/591181.svg)](https://asciinema.org/a/591181)

## 📖 [Documentation](https://docs.helmwave.app?utm_source=github&utm_medium=project)

Documentation available at [docs.helmwave.app](https://docs.helmwave.app?utm_source=github&utm_medium=project)


## Community, discussion, contribution, and support

- <a href="https://t.me/helmwave" ><img src="https://img.shields.io/badge/telegram-chat-179cde.svg?logo=telegram" /></a>
- [discussions](https://github.com/orgs/helmwave/discussions)
- [kanban](https://github.com/orgs/helmwave/projects/3)
- [contribution guide](https://github.com/helmwave/helmwave/blob/main/CONTRIBUTING.md)
- [security and vulnerabilities](https://github.com/helmwave/helmwave/blob/main/SECURITY.md)
- <a href="https://landscape.cncf.io/?selected=helmwave"><img src="https://img.shields.io/badge/CNCF_Landscape-helmwave-blue" alt="CNCF Landscape - helmwave"></a>


## Stargazers over time

[![Stargazers over time](https://starchart.cc/helmwave/helmwave.svg?variant=adaptive)](https://starchart.cc/helmwave/helmwave)

==> helmwave-0.41.1.tar.gz: helmwave-0.41.1/README.md <==
<p align="center">
  <a href="https://docs.helmwave.app?utm_source=github&utm_medium=project"><img alt="helmwave logo" src="https://raw.githubusercontent.com/helmwave/logo/main/signed_logo_top.svg" style="max-height:100%;" height="300px" /></a>
</p>

<p align="center">
  <a href="https://landscape.cncf.io/?selected=helmwave"><img src="https://img.shields.io/badge/CNCF_Landscape-helmwave-blue" alt="CNCF Landscape - helmwave"></a>
  <a href="https://github.com/helmwave/helmwave/blob/main/LICENSE"><img alt="license – MIT" src="https://img.shields.io/github/license/zhilyaev/helmwave"></a>
  <a href="https://bestpractices.coreinfrastructure.org/projects/5426"><img alt="best-practices" src="https://bestpractices.coreinfrastructure.org/projects/5426/badge"></a>
  <a href="https://codecov.io/gh/helmwave/helmwave"><img alt="codecov" src="https://codecov.io/gh/helmwave/helmwave/branch/main/graph/badge.svg?token=0WXxYhIG4S" /></a>
  <a href="https://www.codacy.com/gh/helmwave/helmwave/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=helmwave/helmwave&amp;utm_campaign=Badge_Grade"><img alt="codacy" src="https://app.codacy.com/project/badge/Grade/200ca37690b7463b976f1ece36b53a4e"/></a>
  <a href="https://www.codefactor.io/repository/github/helmwave/helmwave"><img src="https://www.codefactor.io/repository/github/helmwave/helmwave/badge" alt="CodeFactor" /></a>
  <a href="https://goreportcard.com/report/github.com/helmwave/helmwave"><img src="https://goreportcard.com/badge/github.com/helmwave/helmwave" alt="CodeFactor" /></a>
  <img alt="GitHub tag (latest SemVer)" src="https://img.shields.io/github/v/tag/zhilyaev/helmwave?label=latest">
</p>


🌊 Helmwave is **[helm3](https://github.com/helm/helm/)-native** tool for deploy your Helm Charts.

> We focus on speed execution, tiny size, pretty debugging.

With 🌊 helmwave you will become a superhero:

- Deploy multiple environments by one step
- Separate values for environments
- Common values for apps
- Keep a directory of chart value files
- Maintain changes in version control
- Template values
- Step by Step deployment (`depends_on`, `allow_failure`)
- Live tracking kubernetes resources with kubedog
- Fetch data from external datasource like vault, aws sm, sops
- ... and much more!

[![asciicast](https://asciinema.org/a/591181.svg)](https://asciinema.org/a/591181)

## 📖 [Documentation](https://docs.helmwave.app?utm_source=github&utm_medium=project)

Documentation available at [docs.helmwave.app](https://docs.helmwave.app?utm_source=github&utm_medium=project)


## Community, discussion, contribution, and support

- <a href="https://t.me/helmwave" ><img src="https://img.shields.io/badge/telegram-chat-179cde.svg?logo=telegram" /></a>
- [discussions](https://github.com/orgs/helmwave/discussions)
- [kanban](https://github.com/orgs/helmwave/projects/3)
- [contribution guide](https://github.com/helmwave/helmwave/blob/main/CONTRIBUTING.md)
- [security and vulnerabilities](https://github.com/helmwave/helmwave/blob/main/SECURITY.md)
- <a href="https://landscape.cncf.io/?selected=helmwave"><img src="https://img.shields.io/badge/CNCF_Landscape-helmwave-blue" alt="CNCF Landscape - helmwave"></a>


## Stargazers over time

[![Stargazers over time](https://starchart.cc/helmwave/helmwave.svg?variant=adaptive)](https://starchart.cc/helmwave/helmwave)
